@@ -20,13 +20,9 @@ from __future__ import division
 import re
 import numpy as N
 
-# use fast or slow helpers
-slowfuncs = False
-try:
-    from ..helpers.qtloops import numpyToQImage, applyImageTransparancy
-except ImportError:
-    slowfuncs = True
-    from .slowfuncs import slowNumpyToQImage
+from .. import qtall as qt
+
+from ..helpers.qtloops import numpyToQImage, applyImageTransparancy
 
 # Default colormaps used by widgets.
 # Each item in this dict is a colormap entry, with the key the name.
@@ -119,6 +115,225 @@ _defaultmaps = {
         (0,   255, 255, 255),
         (255, 255, 255, 255),
         ),
+
+    # from http://www.kennethmoreland.com/color-maps/
+    'cool-warm': (
+        (59, 76, 192, 255), 
+        (68, 90, 204, 255), 
+        (77, 104, 215, 255), 
+        (87, 117, 225, 255), 
+        (98, 130, 234, 255), 
+        (108, 142, 241, 255), 
+        (119, 154, 247, 255), 
+        (130, 165, 251, 255), 
+        (141, 176, 254, 255), 
+        (152, 185, 255, 255), 
+        (163, 194, 255, 255), 
+        (174, 201, 253, 255), 
+        (184, 208, 249, 255), 
+        (194, 213, 244, 255), 
+        (204, 217, 238, 255), 
+        (213, 219, 230, 255), 
+        (221, 221, 221, 255), 
+        (229, 216, 209, 255), 
+        (236, 211, 197, 255), 
+        (241, 204, 185, 255), 
+        (245, 196, 173, 255), 
+        (247, 187, 160, 255), 
+        (247, 177, 148, 255), 
+        (247, 166, 135, 255), 
+        (244, 154, 123, 255), 
+        (241, 141, 111, 255), 
+        (236, 127, 99, 255), 
+        (229, 112, 88, 255), 
+        (222, 96, 77, 255), 
+        (213, 80, 66, 255), 
+        (203, 62, 56, 255), 
+        (192, 40, 47, 255), 
+        (180, 4, 38, 255),
+        ),
+
+    # from http://geog.uoregon.edu/datagraphics/color_scales.htm
+    'green-magenta': (
+        (0, 80, 0, 255),
+        (0, 134, 0, 255),
+        (0, 187, 0, 255),
+        (0, 241, 0, 255),
+        (80, 255, 80, 255),
+        (134, 255, 134, 255),
+        (187, 255, 187, 255),
+        (255, 255, 255, 255),
+        (255, 241, 255, 255),
+        (255, 187, 255, 255),
+        (255, 134, 255, 255),
+        (255, 80, 255, 255),
+        (241, 0, 241, 255),
+        (187, 0, 187, 255),
+        (134, 0, 134, 255),
+        (80, 0, 80, 255)
+        ),
+
+    'blue-darkred': (
+        (216, 0, 36, 255),
+        (247, 28, 24, 255),
+        (255, 87, 40, 255),
+        (255, 135, 61, 255),
+        (255, 176, 86, 255),
+        (255, 211, 117, 255),
+        (255, 234, 153, 255),
+        (255, 249, 188, 255),
+        (255, 255, 234, 255),
+        (234, 255, 255, 255),
+        (188, 241, 255, 255),
+        (153, 214, 255, 255),
+        (117, 172, 255, 255),
+        (86, 120, 255, 255),
+        (61, 61, 255, 255),
+        (53, 39, 247, 255),
+        (47, 21, 216, 255),
+        (33, 0, 165, 255)
+        ),
+
+    'blue-darkorange': (
+        (102, 102, 0, 255),
+        (153, 153, 0, 255),
+        (204, 204, 0, 255),
+        (255, 255, 0, 255),
+        (255, 255, 51, 255),
+        (255, 255, 101, 255),
+        (255, 255, 153, 255),
+        (255, 255, 178, 255),
+        (255, 255, 203, 255),
+        (255, 255, 229, 255),
+        (203, 229, 255, 255),
+        (153, 202, 255, 255),
+        (101, 173, 255, 255),
+        (51, 142, 255, 255),
+        (0, 110, 255, 255),
+        (0, 85, 204, 255),
+        (0, 61, 153, 255),
+        (0, 39, 102, 255)
+        ),
+
+    'brown-blue': (
+        (0, 25, 51, 255),
+        (0, 47, 102, 255),
+        (53, 96, 153, 255),
+        (122, 155, 204, 255),
+        (151, 175, 216, 255),
+        (205, 218, 242, 255),
+        (255, 253, 204, 255),
+        (255, 248, 153, 255),
+        (255, 239, 101, 255),
+        (255, 227, 50, 255),
+        (204, 169, 0, 255),
+        (153, 122, 0, 255)
+        ),
+
+    'blue-orange': (
+        (255, 42, 0, 255),
+        (255, 101, 25, 255),
+        (255, 153, 50, 255),
+        (255, 204, 101, 255),
+        (255, 237, 153, 255),
+        (255, 255, 204, 255),
+        (204, 255, 255, 255),
+        (153, 238, 255, 255),
+        (101, 204, 255, 255),
+        (50, 153, 255, 255),
+        (25, 102, 255, 255),
+        (0, 42, 255, 255)
+        ),
+
+    'seq': (
+        (15, 15, 153, 255),
+        (44, 44, 178, 255),
+        (81, 81, 204, 255),
+        (126, 126, 229, 255),
+        (178, 178, 255, 255),
+        (15, 84, 153, 255),
+        (44, 111, 178, 255),
+        (81, 142, 204, 255),
+        (126, 177, 229, 255),
+        (178, 216, 255, 255),
+        (15, 153, 107, 255),
+        (44, 178, 133, 255),
+        (81, 204, 163, 255),
+        (126, 229, 195, 255),
+        (178, 255, 229, 255),
+        (153, 107, 15, 255),
+        (178, 133, 44, 255),
+        (204, 163, 81, 255),
+        (229, 195, 126, 255),
+        (255, 229, 178, 255),
+        (153, 15, 38, 255),
+        (178, 44, 66, 255),
+        (204, 81, 101, 255),
+        (229, 126, 143, 255),
+        (255, 178, 191, 255),
+        ),
+    
+    # from https://github.com/visit-vis/VisIt/blob/master/avt/Pipeline/Data/avtColorTables.C 
+    'hot_desaturated': (
+        (219, 71,  71,  255),
+        (91,  0,   0,   255),
+        (255, 255, 0,   255),
+        (0,   127, 0,   255),
+        (0,   255, 255, 255),
+        (0,   96,  255, 255),
+        (0,   0,   107, 255),
+        (76,  76,  224, 255),
+        ),
+    
+    # exported from VisIt color table (http://www.visitusers.org)
+    'yellow-green': (
+        (229, 255, 255, 255),
+        (185, 252, 247, 255),
+        (163, 240, 217, 255),
+        (142, 221, 173, 255),
+        (121, 198, 120, 255),
+        (93,  171, 65,  255),
+        (67,  132, 35,  255),
+        (55,  104, 0,   255),
+        (41,  69,  0,   255),
+        ),
+    'yellow-green-blue': (
+        (217, 255, 255, 255),
+        (177, 248, 237, 255),
+        (180, 233, 199, 255),
+        (187, 205, 127, 255),
+        (196, 182, 65,  255),
+        (192, 145, 29,  255),
+        (168, 94,  34,  255),
+        (148, 52,  37,  255),
+        (88,  29,  8,   255),
+        ),
+    'yellow-orange-brown': (
+        (229, 255, 255, 255),
+        (188, 247, 255, 255),
+        (145, 227, 254, 255),
+        (79,  196, 254, 255),
+        (41,  153, 254, 255),
+        (20,  112, 236, 255),
+        (2,   76,  204, 255),
+        (4,   52,  153, 255),
+        (6,   37,  102, 255),
+        ),
+    'yellow-orange-red': (
+        (204, 255, 255, 255),
+        (160, 237, 255, 255),
+        (118, 217, 254, 255),
+        (76,  178, 254, 255),
+        (60,  141, 253, 255),
+        (42,  78,  252, 255),
+        (28,  26,  227, 255),
+        (38,  0,   189, 255),
+        (38,  0,   128, 255),
+        ),
+
+    'none': (
+        (255, 255, 255, 255),
+    ),
     }
 
 def cubehelix(start, rots, hue, gamma, nlev=64):
@@ -175,6 +390,10 @@ class ColorMaps(object):
     """
 
     def __init__(self):
+        self.wipe()
+
+    def wipe(self):
+        """Reset colormaps to default state."""
         self.maps = dict(_defaultmaps)
 
     def get(self, idx, default=None):
@@ -253,6 +472,12 @@ class ColorMaps(object):
             'royal-step',
             'spectrum-step',
             'transblack-step5',
+            'green-magenta-step16',
+            'blue-darkred-step12',
+            'blue-darkorange-step12',
+            'brown-blue-step12',
+            'blue-orange-step12',
+            'seq-step25',
         ])
         return iter(items)
 
@@ -272,12 +497,12 @@ def applyScaling(data, mode, minval, maxval):
         
     if mode == 'linear':
         # linear scaling
-        data = (data - minval) / (maxval - minval)
+        data = (data - minval) * (1./(maxval - minval))
 
     elif mode == 'sqrt':
         # sqrt scaling
         # translate into fractions of range
-        data = (data - minval) / (maxval - minval)
+        data = (data - minval) * (1./(maxval - minval))
         # clip off any bad sqrts
         data[data < 0.] = 0.
         # actually do the sqrt transform
@@ -288,7 +513,7 @@ def applyScaling(data, mode, minval, maxval):
         with N.errstate(invalid='ignore', divide='ignore'):
             invrange = 1./(N.log(maxval)-N.log(minval))
             data = (N.log(data)-N.log(minval)) * invrange
-        data[~N.isfinite(data)] = 0
+        data[~N.isfinite(data)] = N.nan
 
     elif mode == 'squared':
         # squared scaling
@@ -337,20 +562,15 @@ def applyColorMap(cmap, scaling, datain, minval, maxval,
     # apply scaling of data
     fracs = applyScaling(datain, scaling, minval, maxval)
 
-    if not slowfuncs:
-        img = numpyToQImage(fracs, cmap, transimg is not None)
-        if transimg is not None:
-            applyImageTransparancy(img, transimg)
-    else:
-        img = slowNumpyToQImage(fracs, cmap, transimg)
+    img = numpyToQImage(fracs, cmap, transimg is not None)
+    if transimg is not None:
+        applyImageTransparancy(img, transimg)
     return img
 
 def makeColorbarImage(minval, maxval, scaling, cmap, transparency,
-                      direction='horz'):
+                      direction='horizontal', barsize=128):
     """Make a colorbar for the scaling given."""
 
-    barsize = 128
-
     if scaling in ('linear', 'sqrt', 'squared'):
         # do a linear color scaling
         vals = N.arange(barsize)/(barsize-1.0)*(maxval-minval) + minval
@@ -378,3 +598,24 @@ def makeColorbarImage(minval, maxval, scaling, cmap, transparency,
                         minval, maxval, transparency)
 
     return img
+
+def getColormapArray(cmap, nvals):
+    """Get [R,G,B,alpha] array of nvals for colormap array given.
+
+    number of values to return is given by nvals
+    """
+
+    img = makeColorbarImage(0, 1, 'linear', cmap, 0, barsize=nvals)
+
+    # ensure data are stored in the correct order
+    fmt = qt.QImage.Format_ARGB32
+    if img.format() != fmt:
+        img = img.convertToFormat(fmt)
+
+    # convert image pointer to numpy array (assumes nvals*4 bytes)
+    cv = N.array(img.constScanLine(0).asarray(nvals*4)).reshape((nvals,4))
+
+    # swap into RGBA
+    cv = N.column_stack(( cv[:,2], cv[:,1], cv[:,0], cv[:,3] ))
+
+    return cv
