@@ -21,9 +21,10 @@ positions."""
 
 from __future__ import division
 import numpy as N
+import re
 
 from ..compat import czip
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
 from .. import setting
 from .. import utils
@@ -36,7 +37,7 @@ from . import controlgraph
 
 def _(text, disambiguation=None, context='Axis'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class MajorTick(setting.Line):
     '''Major tick settings.'''
@@ -166,6 +167,124 @@ class TickLabel(setting.Text):
                                                 'labels from axis'),
                                       usertext= _('Tick offset') ) )
 
+class AutoRange(setting.ChoiceOrMore):
+    """Choose how to choose range of axis."""
+
+    # +5% or -5%
+    re_dr_plusminus = re.compile(r'^\s*([+-][0-9]+)\s*%\s*$')
+    # 5-10%
+    re_dr_percrange = re.compile(r'^\s*(-?[0-9]+)\s*-\s*([0-9]+)\s*%\s*$')
+    # < 5%
+    re_dr_lower = re.compile(r'^\s*<\s*([0-9]+)\s*%\s*$')
+    # > 95%
+    re_dr_upper = re.compile(r'^\s*>\s*([0-9]+)\s*%\s*$')
+
+    def __init__(self, name, value, **args):
+        setting.ChoiceOrMore.__init__(
+            self,
+            'autoRange',
+            ('exact', 'next-tick',
+             '+2%', '+5%', '+10%', '+15%',
+             '-2%', '-5%', '-10%', '-15%',
+             '20-80%', '<20%', '>80%',
+            ),
+            'next-tick',
+            descr = _('If axis range not specified, use range of '
+                      'data and this setting'),
+            descriptions = (
+                _('Use exact data range'),
+                _('Round up to tick marks from data range'),
+                _('Expand 2% beyond data range'),
+                _('Expand 5% beyond data range'),
+                _('Expand 10% beyond data range'),
+                _('Expand 15% beyond data range'),
+                _('Shrink 2% inside data range'),
+                _('Shrink 5% inside data range'),
+                _('Shrink 10% inside data range'),
+                _('Shrink 15% inside data range'),
+                _('20 to 80% of the data range'),
+                _('Up to 20% of the data range'),
+                _('Above 80% of the data range'),
+            ),
+            formatting = True,
+            usertext = _('Auto range'),
+            )
+
+    def copy(self):
+        """Return copy of this setting."""
+        return self._copyHelper((), (), {})
+
+    def autoRangeToFracs(self, rng, doc):
+        """Convert auto range setting to fractions to expand range by.
+
+        Returns tuple of expansion fractions for left and right
+        """
+
+        # +X% or -Y%
+        m = self.re_dr_plusminus.match(rng)
+        if m:
+            v = float(m.group(1))*0.01
+            return v, v
+
+        # X-Y%
+        m = self.re_dr_percrange.match(rng)
+        if m:
+            v1 = -float(m.group(1))*0.01
+            v2 = -(1-float(m.group(2))*0.01)
+            return v1, v2
+
+        # <X%
+        m = self.re_dr_lower.match(rng)
+        if m:
+            return 0, -(1-float(m.group(1))*0.01)
+
+        # >Y%
+        m = self.re_dr_upper.match(rng)
+        if m:
+            return -(float(m.group(1))*0.01), 0
+
+        # error
+        doc.log(_("Invalid axis range '%s'") % rng)
+        return 0, 0
+
+    def adjustPlottedRange(self, plottedrange, adjustmin, adjustmax, log, doc):
+        """Adjust plotted range list given settings.
+        plottedrange: [minval, maxval]
+        adjustmin/adjustmax: bool whether to adjust
+        log: is log axis
+        doc: Document object
+        """
+        rng = self.val
+        if rng == 'exact':
+            pass
+        elif rng == 'next-tick':
+            pass
+        else:
+            # get fractions to expand range by
+            expandfrac1, expandfrac2 = self.autoRangeToFracs(
+                rng, doc)
+            origrange = list(plottedrange)
+            if log:
+                # logarithmic
+                logrng = abs( N.log(plottedrange[1]) -
+                           N.log(plottedrange[0]) )
+                if adjustmin:
+                    plottedrange[0] /= N.exp(logrng * expandfrac1)
+                if adjustmax:
+                    plottedrange[1] *= N.exp(logrng * expandfrac2)
+            else:
+                # linear
+                rng = plottedrange[1] - plottedrange[0]
+                if adjustmin:
+                    plottedrange[0] -= rng*expandfrac1
+                if adjustmax:
+                    plottedrange[1] += rng*expandfrac2
+
+            # if order is wrong, then give error!
+            if plottedrange[1] <= plottedrange[0]:
+                doc.log(_("Invalid axis range '%s'") % rng)
+                plottedrange[:] = origrange
+
 ###############################################################################
 
 class Axis(widget.Widget):
@@ -182,9 +301,6 @@ class Axis(widget.Widget):
         widget.Widget.__init__(self, parent, name=name)
         s = self.settings
 
-        if type(self) == Axis:
-            self.readDefaults()
-
         if self.name == 'y' and s.direction != 'vertical':
             s.direction = 'vertical'
         elif self.name == 'x' and s.direction != 'horizontal':
@@ -196,6 +312,7 @@ class Axis(widget.Widget):
         # document updates change set variable when things need recalculating
         self.docchangeset = -1
         self.currentbounds = [0,0,1,1]
+        self.plottedrange = [0., 1.]
 
     @classmethod
     def addSettings(klass, s):
@@ -213,21 +330,7 @@ class Axis(widget.Widget):
         s.add( setting.Bool('log', False,
                             descr = _('Whether axis is logarithmic'),
                             usertext=_('Log')) )
-        s.add( setting.Choice(
-                'autoRange',
-                ('exact', 'next-tick', '+2%', '+5%', '+10%', '+15%'),
-                'next-tick',
-                descr = _('If axis range not specified, use range of '
-                          'data and this setting'),
-                descriptions = (_('Use exact data range'),
-                                _('Use data range, rounding up to tick marks'),
-                                _('Use data range, adding 2% of range'),
-                                _('Use data range, adding 5% of range'),
-                                _('Use data range, adding 10% of range'),
-                                _('Use data range, adding 15% of range'),
-                                ),
-                formatting = True,
-                usertext = _('Auto range') ) )
+        s.add( AutoRange('autoRange', 'next-tick') )
         s.add( setting.Choice('mode',
                               ('numeric', 'datetime', 'labels'),
                               'numeric',
@@ -358,6 +461,7 @@ class Axis(widget.Widget):
         """Return whether any of the bounds are automatically determined."""
         return self.settings.min == 'Auto' or self.settings.max == 'Auto'
 
+
     def computePlottedRange(self, force=False, overriderange=None):
         """Convert the range requested into a plotted range."""
 
@@ -419,29 +523,8 @@ class Axis(widget.Widget):
             if self.plottedrange[0] == self.plottedrange[1]:
                 self.plottedrange[1] = self.plottedrange[0]*2
 
-        r = s.autoRange
-        if r == 'exact':
-            pass
-        elif r == 'next-tick':
-            pass
-        else:
-            val = {'+2%': 0.02, '+5%': 0.05, '+10%': 0.1, '+15%': 0.15}[r]
-
-            if s.log:
-                # logarithmic
-                logrng = abs( N.log(self.plottedrange[1]) -
-                           N.log(self.plottedrange[0]) )
-                if s.min == 'Auto':
-                    self.plottedrange[0] /= N.exp(logrng * val)
-                if s.max == 'Auto':
-                    self.plottedrange[1] *= N.exp(logrng * val)
-            else:
-                # linear
-                rng = self.plottedrange[1] - self.plottedrange[0]
-                if s.min == 'Auto':
-                    self.plottedrange[0] -= rng*val
-                if s.max == 'Auto':
-                    self.plottedrange[1] += rng*val
+        s.get('autoRange').adjustPlottedRange(
+            self.plottedrange, s.min=='Auto', s.max=='Auto', s.log, self.document)
 
         self.computeTicks()
 
@@ -457,6 +540,10 @@ class Axis(widget.Widget):
         return (self.settings.log and
                 self.settings.mode in ('numeric', 'labels'))
 
+    def isLinear(self):
+        """Is this a linear axis?"""
+        return not self.settings.log
+
     def computeTicks(self, allowauto=True):
         """Update ticks given plotted range.
         if allowauto is False, then do not allow ticks to be
@@ -654,9 +741,9 @@ class Axis(widget.Widget):
     def swapline(self, painter, a1, b1, a2, b2):
         """Draw line, but swap x & y coordinates if vertical axis."""
         if self.settings.direction == 'horizontal':
-            painter.drawLine(qt4.QPointF(a1, b1), qt4.QPointF(a2, b2))
+            painter.drawLine(qt.QPointF(a1, b1), qt.QPointF(a2, b2))
         else:
-            painter.drawLine(qt4.QPointF(b1, a1), qt4.QPointF(b2, a2))
+            painter.drawLine(qt.QPointF(b1, a1), qt.QPointF(b2, a2))
 
     def swaplines(self, painter, a1, b1, a2, b2):
         """Multiline version of swapline where a1, b1, a2, b2 are arrays."""
@@ -685,11 +772,11 @@ class Axis(widget.Widget):
                        coordticks, coordticks*0.+self.coordPerp1,
                        coordticks, coordticks*0.+self.coordPerp2)
 
-    def _drawAxisLine(self, painter):
+    def _drawAxisLine(self, painter, posn):
         """Draw the line of the axis."""
 
         pen = self.settings.get('Line').makeQPen(painter)
-        pen.setCapStyle(qt4.Qt.FlatCap)
+        pen.setCapStyle(qt.Qt.FlatCap)
         painter.setPen(pen)
         self.swapline( painter,
                        self.coordParr1, self.coordPerp,
@@ -701,7 +788,7 @@ class Axis(widget.Widget):
         s = self.settings
         mt = s.get('MinorTicks')
         pen = mt.makeQPen(painter)
-        pen.setCapStyle(qt4.Qt.FlatCap)
+        pen.setCapStyle(qt.Qt.FlatCap)
         painter.setPen(pen)
         delta = mt.getLength(painter)
 
@@ -723,7 +810,7 @@ class Axis(widget.Widget):
         s = self.settings
         mt = s.get('MajorTicks')
         pen = mt.makeQPen(painter)
-        pen.setCapStyle(qt4.Qt.FlatCap)
+        pen.setCapStyle(qt.Qt.FlatCap)
         painter.setPen(pen)
         startdelta = mt.getLength(painter)
         delta = startdelta
@@ -757,7 +844,7 @@ class Axis(widget.Widget):
         for plotter in plotters:
             # get label and label coordinates from plotter (if any)
             labels, coords = plotter.getAxisLabels(dir)
-            if None not in (labels, coords):
+            if labels is not None and coords is not None:
                 # convert coordinates to plotter coordinates
                 pcoords = self._graphToPlotter(coords)
                 for coord, pcoord, lab in czip(coords, pcoords, labels):
@@ -798,7 +885,7 @@ class Axis(widget.Widget):
         # get information about text scales
         tl = s.get('TickLabels')
         scale = tl.scale
-        pen = tl.makeQPen()
+        pen = tl.makeQPen(painter)
 
         # an extra offset if required
         self._delta_axis += tl.get('offset').convert(painter)
@@ -835,8 +922,11 @@ class Axis(widget.Widget):
             else:
                 x, y = parlposn, perpposn
 
-            r = utils.Renderer(painter, font, x, y, text, alignhorz=ax,
-                               alignvert=ay, angle=angle)
+            r = utils.Renderer(
+                painter, font, x, y, text, alignhorz=ax,
+                alignvert=ay, angle=angle,
+                doc=self.document)
+
             if outerbounds is not None:
                 # make sure ticks are within plot
                 if vertical:
@@ -940,16 +1030,18 @@ class Axis(widget.Widget):
                     x = outerbounds[2]
                     ax = -ax
 
-        r = utils.Renderer(painter, font, x, y, text,
-                           ax, ay, angle,
-                           usefullheight = True)
+        r = utils.Renderer(
+            painter, font, x, y, text,
+            ax, ay, angle,
+            usefullheight=True,
+            doc=self.document)
 
         # make sure text is in plot rectangle
         if outerbounds is not None:
             r.ensureInBox( minx=outerbounds[0], maxx=outerbounds[2],
                            miny=outerbounds[1], maxy=outerbounds[3] )
 
-        texttorender.insert(0, (r, s.get('Label').makeQPen()) )
+        texttorender.insert(0, (r, s.get('Label').makeQPen(painter)) )
 
     def chooseName(self):
         """Get default name for axis. Make x and y axes, then axisN."""
@@ -1012,9 +1104,9 @@ class Axis(widget.Widget):
 
         with painter:
             painter.save()
-            painter.setClipRect( qt4.QRectF(
-                    qt4.QPointF(parentposn[0], parentposn[1]),
-                    qt4.QPointF(parentposn[2], parentposn[3]) ) )
+            painter.setClipRect( qt.QRectF(
+                qt.QPointF(parentposn[0], parentposn[1]),
+                qt.QPointF(parentposn[2], parentposn[3]) ) )
 
             if not s.MinorGridLines.hide:
                 coordminorticks = self._graphToPlotter(self.minortickscalc)
@@ -1040,7 +1132,7 @@ class Axis(widget.Widget):
         # temporarily change position of axis to other side for drawing
         self.updateAxisLocation(posn, otherposition=otheredge)
         if not s.Line.hide:
-            self._drawAxisLine(painter)
+            self._drawAxisLine(painter, posn)
         if not s.MinorTicks.hide:
             self._drawMinorTicks(painter, coordminorticks)
         if not s.MajorTicks.hide:
@@ -1110,8 +1202,8 @@ class Axis(widget.Widget):
 
         # make control item for axis
         phelper.setControlGraph(self, [ controlgraph.ControlAxisLine(
-                    self, s.direction, self.coordParr1,
-                    self.coordParr2, self.coordPerp, posn) ])
+            self, phelper, s.direction, self.coordParr1,
+            self.coordParr2, self.coordPerp, posn) ])
 
         # get tick vals
         coordticks = self._graphToPlotter(self.majortickscalc)
@@ -1128,7 +1220,7 @@ class Axis(widget.Widget):
 
         # plot the line along the axis
         if not s.Line.hide:
-            self._drawAxisLine(painter)
+            self._drawAxisLine(painter, posn)
 
         # plot minor ticks
         if not s.MinorTicks.hide:
