@@ -22,7 +22,7 @@ from __future__ import division
 import math
 
 from ..compat import crange, citems
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
 from .. import setting
 from .. import utils
@@ -32,7 +32,7 @@ from . import controlgraph
 
 def _(text, disambiguation=None, context='Key'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 #############################################################################
 # classes for controlling key position interactively
@@ -48,7 +48,7 @@ class ControlKey(object):
         parentposn: posn of parent on plot
         xpos, ypos: position of key
         width, height: size of key
-        textheight: 
+        textheight: height of text
         """
         self.widget = widget
         self.parentposn = tuple(parentposn)
@@ -60,22 +60,22 @@ class ControlKey(object):
     def createGraphicsItem(self, parent):
         return _GraphControlKey(parent, self)
 
-class _GraphControlKey(qt4.QGraphicsRectItem, controlgraph._ScaledShape):
+class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
     """The graphical rectangle which is dragged around to reposition
     the key."""
 
     def __init__(self, parent, params):
-        qt4.QGraphicsRectItem.__init__(self, parent)
+        qt.QGraphicsRectItem.__init__(self, parent)
 
         self.params = params
         self.setScaledRect(
             params.posn[0], params.posn[1],
             params.dims[0], params.dims[1])
 
-        self.setCursor(qt4.Qt.SizeAllCursor)
+        self.setCursor(qt.Qt.SizeAllCursor)
         self.setZValue(1.)
-        self.setFlag(qt4.QGraphicsItem.ItemIsMovable)
-        self.highlightpen = qt4.QPen(qt4.Qt.red, 2, qt4.Qt.DotLine)
+        self.setFlag(qt.QGraphicsItem.ItemIsMovable)
+        self.highlightpen = qt.QPen(qt.Qt.red, 2, qt.Qt.DotLine)
 
         pposn, dims = params.parentposn, params.dims
         th = params.textheight
@@ -96,7 +96,7 @@ class _GraphControlKey(qt4.QGraphicsRectItem, controlgraph._ScaledShape):
         self.highlightpoints = {}
         for xname, xval in citems(xposn):
             for yname, yval in citems(yposn):
-                self.highlightpoints[(xname, yname)] = qt4.QPointF(
+                self.highlightpoints[(xname, yname)] = qt.QPointF(
                     xval*params.cgscale, yval*params.cgscale)
 
         self.updatePen()
@@ -109,7 +109,7 @@ class _GraphControlKey(qt4.QGraphicsRectItem, controlgraph._ScaledShape):
         rect.translate(self.pos())
 
         highlight = None
-        highlightrect = qt4.QRectF(rect.left()-10, rect.top()-10, 20, 20)
+        highlightrect = qt.QRectF(rect.left()-10, rect.top()-10, 20, 20)
         for name, point in citems(self.highlightpoints):
             if highlightrect.contains(point):
                 highlight = name
@@ -125,12 +125,12 @@ class _GraphControlKey(qt4.QGraphicsRectItem, controlgraph._ScaledShape):
 
     def mouseMoveEvent(self, event):
         """Set correct pen for box."""
-        qt4.QGraphicsRectItem.mouseMoveEvent(self, event)
+        qt.QGraphicsRectItem.mouseMoveEvent(self, event)
         self.updatePen()
 
     def mouseReleaseEvent(self, event):
         """Update widget with position."""
-        qt4.QGraphicsRectItem.mouseReleaseEvent(self, event)
+        qt.QGraphicsRectItem.mouseReleaseEvent(self, event)
         highlight = self.checkHighlight()
         if highlight:
             # in a highlight zone so use highlight zone name to set position
@@ -171,71 +171,94 @@ class Key(widget.Widget):
         """Construct list of settings."""
         widget.Widget.addSettings(s)
 
-        s.add( setting.Text('Text',
-                            descr = _('Text settings'),
-                            usertext=_('Text')),
+        s.add( setting.Text(
+            'Text',
+            descr = _('Text settings'),
+            usertext=_('Text')),
                pixmap = 'settings_axislabel' )
-        s.add( setting.KeyBrush('Background',
-                                descr = _('Key background fill'),
-                                usertext=_('Background')),
+
+        s.add( setting.Str(
+            'order', '',
+            descr=_('Override default item order (comma separated names)'),
+            usertext=_('Order')))
+
+        s.add( setting.Str(
+            'exclude', '',
+            descr=_('Exclude item from displaying (comma separated names)'),
+            usertext=_('Exclude')))
+
+        s.add( setting.Str(
+            'title', '',
+            descr=_('Key title text'),
+            usertext=_('Title')), 0 )
+
+        s.add( setting.KeyBrush(
+            'Background',
+            descr = _('Key background fill'),
+            usertext=_('Background')),
                pixmap = 'settings_bgfill' )
-        s.add( setting.Line('Border',
-                            descr = _('Key border line'),
-                            usertext=_('Border')),
+        s.add( setting.Line(
+            'Border',
+            descr = _('Key border line'),
+            usertext=_('Border')),
                pixmap = 'settings_border' )
 
-        s.add( setting.Str('title', '',
-                           descr=_('Key title text'),
-                           usertext=_('Title')) )
+        s.add( setting.AlignHorzWManual(
+            'horzPosn',
+            'right',
+            descr = _('Horizontal key position'),
+            usertext=_('Horz posn'),
+            formatting=True) )
+        s.add( setting.AlignVertWManual(
+            'vertPosn',
+            'bottom',
+            descr = _('Vertical key position'),
+            usertext=_('Vert posn'),
+            formatting=True) )
 
-        s.add( setting.AlignHorzWManual( 'horzPosn',
-                                         'right',
-                                         descr = _('Horizontal key position'),
-                                         usertext=_('Horz posn'),
-                                         formatting=True) )
-        s.add( setting.AlignVertWManual( 'vertPosn',
-                                         'bottom',
-                                         descr = _('Vertical key position'),
-                                         usertext=_('Vert posn'),
-                                         formatting=True) )
-                               
-        s.add( setting.Distance('keyLength',
-                                '1cm',
-                                descr = _('Length of line to show in sample'),
-                                usertext=_('Key length'),
-                                formatting=True) )
-        
-        s.add( setting.AlignVert( 'keyAlign',
-                                  'top',
-                                  descr = _('Alignment of key symbols relative to text'),
-                                  usertext = _('Key alignment'),
-                                  formatting = True) )
+        s.add( setting.Distance(
+            'keyLength',
+            '1cm',
+            descr = _('Length of line to show in sample'),
+            usertext=_('Key length'),
+            formatting=True) )
 
-        s.add( setting.Float( 'horzManual',
-                              0.,
-                              descr = _('Manual horizontal fractional position'),
-                              usertext=_('Horz manual'),
-                              formatting=True) )
-        s.add( setting.Float( 'vertManual',
-                              0.,
-                              descr = _('Manual vertical fractional position'),
-                              usertext=_('Vert manual'),
-                              formatting=True) )
+        s.add( setting.AlignVert(
+            'keyAlign',
+            'top',
+            descr = _('Alignment of key symbols relative to text'),
+            usertext = _('Key alignment'),
+            formatting=True) )
 
-        s.add( setting.Float( 'marginSize',
-                              1.,
-                              minval = 0.,
-                              descr = _('Width of margin in characters'),
-                              usertext=_('Margin size'),
-                              formatting=True) )
+        s.add( setting.Float(
+            'horzManual',
+            0.,
+            descr = _('Manual horizontal fractional position'),
+            usertext=_('Horz manual'),
+            formatting=True) )
+        s.add( setting.Float(
+            'vertManual',
+            0.,
+            descr = _('Manual vertical fractional position'),
+            usertext=_('Vert manual'),
+            formatting=True) )
 
-        s.add( setting.Int( 'columns',
-                            1,
-                            descr = _('Number of columns in key'),
-                            usertext = _('Columns'),
-                            minval = 1,
-                            maxval = 100,
-                            formatting = True) )
+        s.add( setting.Float(
+            'marginSize',
+            1.,
+            minval = 0.,
+            descr = _('Width of margin in characters'),
+            usertext=_('Margin size'),
+            formatting=True) )
+
+        s.add( setting.Int(
+            'columns',
+            1,
+            descr = _('Number of columns in key'),
+            usertext = _('Columns'),
+            minval = 1,
+            maxval = 100,
+            formatting = True) )
 
         s.add( setting.Bool(
             'symbolswap',
@@ -267,42 +290,42 @@ class Key(widget.Widget):
             if lines > numrows:
                 # this layout failed, suggest expanding the box to |lines|
                 return ([], [], lines)
-            
+
             # col -> yp, row -> xp
             layout.append( (plotter, num, col, row, lines) )
             row += lines
             colstats[col] += 1
-        
+
         return (layout, colstats, numrows)
-    
+
     def _layout(self, entries, totallines):
         """Layout the items, trying to keep the box as small as possible
         while still filling the columns"""
-        
+
         maxcols = self.settings.columns
         numcols = min(maxcols, max(len(entries), 1))
-        
+
         if not entries:
             return (list(), (0, 0))
-        
+
         # start with evenly-sized rows and expand to fit
         numrows = totallines // numcols
         layout = []
-        
+
         while not layout:
             # try to do a first cut of the layout, and expand the box until
             # everything fits
             (layout, colstats, newrows) = self._layoutChunk(entries, (0, 0), (numrows, numcols))
             if not layout:
                 numrows = newrows
-            
+
         # ok, we've got a layout where everything fits, now pull items right
         # to fill the remaining columns, if need be
         while colstats[-1] == 0:
             # shift 1 item to the right, up to the first column that has
             # excess items
             meanoccupation = max(1, sum(colstats)/numcols)
-            
+
             # loop until we find a victim item which can be safely moved
             victimcol = numcols
             while True:
@@ -311,14 +334,14 @@ class Key(widget.Widget):
                     if colstats[i] > meanoccupation:
                         victimcol = i
                         break
-                
+
                 # find the last item in the victim column
                 victim = 0
                 for i in reversed(crange(len(layout))):
                     if layout[i][2] == victimcol:
                         victim = i
                         break
-                
+
                 # try to relayout with the victim item shoved to the next column
                 (newlayout, newcolstats, newrows) = self._layoutChunk(entries[victim:],
                                                         (0, victimcol+1), (numrows, numcols))
@@ -329,13 +352,13 @@ class Key(widget.Widget):
                     del colstats[victimcol+1:]
                     colstats += newcolstats[victimcol+1:]
                     break
-                
+
                 # if we've run out of potential victims, just return what we have
                 if victimcol == 0:
                     return (layout, (numrows, numcols))
-        
+
         return (layout, (numrows, numcols))
-    
+
     def draw(self, parentposn, phelper, outerbounds = None):
         """Plot the key on a plotter."""
 
@@ -364,7 +387,7 @@ class Key(widget.Widget):
         # reserve space for the title
         titlewidth, titleheight = 0, 0
         if s.title != '':
-            titlefont = qt4.QFont(font)
+            titlefont = qt.QFont(font)
             titlefont.setPointSize(max(font.pointSize() * 1.2, font.pointSize() + 2))
             titlewidth, titleheight = utils.Renderer(
                 painter, titlefont,
@@ -375,27 +398,40 @@ class Key(widget.Widget):
         # maximum width of text required
         maxwidth = 1
 
+        if s.order:
+            # user specified list if widgets
+            namemap = { c.name: c for c in self.parent.children }
+            orderlist = [x.strip() for x in s.order.split(',')]
+            widgets = [namemap[n] for n in orderlist if n in namemap]
+        else:
+            # default order
+            widgets = [c for c in self.parent.children]
+
+        # which widgets to exclude
+        exclude = { x.strip() for x in s.exclude.split(',') }
+
         entries = []
-        # iterate over children and find widgets which are suitable
-        for c in self.parent.children:
+        for c in widgets:
+            if c.name in exclude or c.settings.hide:
+                continue
             try:
                 num = c.getNumberKeys()
             except AttributeError:
                 continue
-            if not c.settings.hide:
-                # add an entry for each key entry for each widget
-                for i in crange(num):
-                    lines = 1
-                    if showtext:
-                        w, h = utils.Renderer(
-                            painter, font, 0, 0,
-                            c.getKeyText(i),
-                            doc=self.document).getDimensions()
-                        maxwidth = max(maxwidth, w)
-                        lines = max(1, math.ceil(h/height))
 
-                    totallines += lines
-                    entries.append( (c, i, lines) )
+            # add an entry for each key entry for each widget
+            for i in crange(num):
+                lines = 1
+                if showtext:
+                    w, h = utils.Renderer(
+                        painter, font, 0, 0,
+                        c.getKeyText(i),
+                        doc=self.document).getDimensions()
+                    maxwidth = max(maxwidth, w)
+                    lines = max(1, math.ceil(h/height))
+
+                totallines += lines
+                entries.append( (c, i, lines) )
 
         # layout the box
         layout, (numrows, numcols) = self._layout(entries, totallines)
@@ -442,8 +478,8 @@ class Key(widget.Widget):
         boxdims = (totalwidth, totalheight)
 
         # draw surrounding box
-        boxpath = qt4.QPainterPath()
-        boxpath.addRect(qt4.QRectF(x, y, totalwidth, totalheight))
+        boxpath = qt.QPainterPath()
+        boxpath.addRect(qt.QRectF(x, y, totalwidth, totalheight))
         if not s.Background.hide:
             utils.brushExtFillPath(painter, s.Background, boxpath)
         if not s.Border.hide:
