@@ -24,7 +24,7 @@ import itertools
 import numpy as N
 
 from ..compat import czip
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import document
 from .. import utils
@@ -34,19 +34,20 @@ from . import plotters
 
 def _(text, disambiguation=None, context='Line'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class Line(plotters.FreePlotter):
     """A line on the plot/graph."""
     typename='line'
     description=_('Line or arrow')
     allowusercreation = True
-    
-    def __init__(self, parent, name=None):
-        """Construct plotter."""
-        plotters.FreePlotter.__init__(self, parent, name=name)
-        if type(self) == Line:
-            self.readDefaults()
+
+    @staticmethod
+    def showOrHideSetn(v):
+        """Whether to show or hide length/angle or position."""
+        a = ('length', 'angle')
+        b = ('xPos2', 'yPos2')
+        return (a,b) if v=='length-angle' else (b,a)
 
     @classmethod
     def addSettings(klass, s):
@@ -54,41 +55,42 @@ class Line(plotters.FreePlotter):
         plotters.FreePlotter.addSettings(s)
 
         s.add( setting.ChoiceSwitch(
-                'mode',
-                ('length-angle', 'point-to-point'),
-                'length-angle',
-                descr=_('Provide line position and length,angle or '
-                        'first and second points'),
-                usertext=_('Mode'),
-                formatting=False,
-                showfn = lambda val: val == 'length-angle',
-                settingstrue = ('length', 'angle'),
-                settingsfalse = ('xPos2', 'yPos2'),
-                ), 0)
+            'mode',
+            ('length-angle', 'point-to-point'),
+            'length-angle',
+            descr=_('Provide line position and length,angle or '
+                    'first and second points'),
+            usertext=_('Mode'),
+            formatting=False,
+            showfn=klass.showOrHideSetn), 0)
 
         s.add( setting.DatasetExtended(
-                'length', [0.2],
-                descr=_('List of fractional lengths, dataset or expression'),
-                usertext=_('Lengths'),
-                formatting=False), 4 )
+            'length',
+            [0.2],
+            descr=_('List of fractional lengths, dataset or expression'),
+            usertext=_('Lengths'),
+            formatting=False), 4 )
         s.add( setting.DatasetExtended(
-                'angle', [0.],
-                descr=_('List of angle of lines, dataset or expression '
-                        '(degrees)'),
-                usertext=_('Angles'),
-                formatting=False), 5 )
+            'angle',
+            [0.],
+            descr=_('List of angle of lines, dataset or expression '
+                    '(degrees)'),
+            usertext=_('Angles'),
+            formatting=False), 5 )
         s.add( setting.DatasetExtended(
-                'xPos2', [1.],
-                descr=_('List of fractional X coordinates, dataset or '
-                        'expression for point 2'),
-                usertext=_('X positions 2'),
-                formatting=False), 6 )
+            'xPos2',
+            [1.],
+            descr=_('List of fractional X coordinates, dataset or '
+                    'expression for point 2'),
+            usertext=_('X positions 2'),
+            formatting=False), 6 )
         s.add( setting.DatasetExtended(
-                'yPos2', [1.],
-                descr=_('List of fractional Y coordinates, dataset or '
-                        'expression for point 2'),
-                usertext=_('Y positions 2'),
-                formatting=False), 7 )
+            'yPos2',
+            [1.],
+            descr=_('List of fractional Y coordinates, dataset or '
+                    'expression for point 2'),
+            usertext=_('Y positions 2'),
+            formatting=False), 7 )
 
         s.add( setting.Bool('clip', False,
                             descr=_('Clip line to its container'),
@@ -192,8 +194,9 @@ class Line(plotters.FreePlotter):
         # now do the drawing
         clip = None
         if s.clip:
-            clip = qt4.QRectF( qt4.QPointF(posn[0], posn[1]),
-                               qt4.QPointF(posn[2], posn[3]) )
+            clip = qt.QRectF(
+                qt.QPointF(posn[0], posn[1]),
+                qt.QPointF(posn[2], posn[3]))
         painter = phelper.painter(self, posn, clip=clip)
         with painter:
             # adjustable positions for the lines
@@ -203,13 +206,13 @@ class Line(plotters.FreePlotter):
             if not s.Line.hide:
                 painter.setPen( s.get('Line').makeQPen(painter) )
             else:
-                painter.setPen( qt4.QPen(qt4.Qt.NoPen) )
+                painter.setPen( qt.QPen(qt.Qt.NoPen) )
 
             # settings for fill
             if not s.Fill.hide:
-                painter.setBrush( s.get('Fill').makeQBrush() )
+                painter.setBrush( s.get('Fill').makeQBrush(painter) )
             else:
-                painter.setBrush( qt4.QBrush() )
+                painter.setBrush( qt.QBrush() )
 
             # iterate over positions
             scaling = posn[2]-posn[0]
@@ -224,14 +227,15 @@ class Line(plotters.FreePlotter):
             controlgraphitems = []
             for index, (x, y, l, a) in enumerate(lines):
 
-                utils.plotLineArrow(painter, x, y, l, a,
-                                    arrowsize=arrowsize,
-                                    arrowleft=s.arrowleft,
-                                    arrowright=s.arrowright)
+                utils.plotLineArrow(
+                    painter, x, y, l, a,
+                    arrowsize=arrowsize,
+                    arrowleft=s.arrowleft,
+                    arrowright=s.arrowright)
 
                 if isnotdataset:
                     cgi = controlgraph.ControlLine(
-                        self, x, y,
+                        self, phelper, x, y,
                         x + l*math.cos(a/180.*math.pi),
                         y + l*math.sin(a/180.*math.pi))
                     cgi.index = index
@@ -250,7 +254,12 @@ class Line(plotters.FreePlotter):
         if xpos is None or ypos is None:
             return
 
-        x, y = list(s.xPos), list(s.yPos)
+        x = s.get('xPos').getFloatArray(self.document)
+        y = s.get('yPos').getFloatArray(self.document)
+        if x is None or y is None:
+            return
+        x, y = list(x), list(y)
+
         idx = min(cgi.index, len(x)-1)
         if not N.allclose(x[idx], xpos[0]):
             x[idx] = utils.round2delt(xpos[0], xpos[1])
@@ -275,7 +284,12 @@ class Line(plotters.FreePlotter):
             ldelt, adelt = la(pt2[0]+1, pt2[1]+1)
 
             # update values
-            l, a = list(s.length), list(s.angle)
+            l = s.get('length').getFloatArray(self.document)
+            a = s.get('angle').getFloatArray(self.document)
+            if l is None or a is None:
+                return
+            l, a = list(l), list(a)
+
             idx = min(cgi.index, len(l)-1)
             if abs(l[idx]-length) > 1e-8:
                 l[idx] = utils.round2delt(length, ldelt)
@@ -286,12 +300,16 @@ class Line(plotters.FreePlotter):
             operations += [
                 document.OperationSettingSet(s.get('length'), l),
                 document.OperationSettingSet(s.get('angle'), a),
-                ]
+            ]
         else:
             xpos2, ypos2 = self._getGraphCoords(
                 cgi.widgetposn, [pt2[0], pt2[0]+1], [pt2[1], pt2[1]+1])
             if xpos2 is not None and ypos2 is not None:
-                x2, y2 = list(s.xPos2), list(s.yPos2)
+                x2 = s.get('xPos2').getFloatArray(self.document)
+                y2 = s.get('yPos2').getFloatArray(self.document)
+                if x2 is None or y2 is None:
+                    return
+                x2, y2 = list(x2), list(y2)
 
                 idx = min(cgi.index, len(x2)-1)
                 if not N.allclose(x2[idx], xpos2[0]):
@@ -303,7 +321,7 @@ class Line(plotters.FreePlotter):
                 operations += [
                     document.OperationSettingSet(s.get('xPos2'), x2),
                     document.OperationSettingSet(s.get('yPos2'), y2)
-                    ]
+                ]
 
         self.document.applyOperation(
             document.OperationMultiple(operations, descr=_('adjust lines')) )
