@@ -19,13 +19,10 @@
 ###############################################################################
 
 from __future__ import division
-from .. import qtall as qt4
+from .. import qtall as qt
 import numpy as N
 
-try:
-    from ..helpers.qtloops import plotPathsToPainter
-except ImportError:
-    from .slowfuncs import plotPathsToPainter
+from ..helpers.qtloops import plotPathsToPainter
 
 from . import colormap
 
@@ -110,6 +107,11 @@ linesymbols = {
                              ((2, 0), (0, 0), (0, -2)),
                              ((1, -0.8), (2, 0), (1, 0.8)) ),
 
+    'lineup': ( ((0, 0), (0, -1)), ),
+    'linedown': ( ((0, 0), (0, 1)), ),
+    'lineleft': ( ((0, 0), (-1, 0)), ),
+    'lineright': ( ((0, 0), (1, 0)), ),
+
     # for arrows
     '_linearrow': ( ((-1.8, -1), (0, 0), (-1.8, 1)), ),
     '_linearrowreverse': ( ((1.8, -1), (0, 0), (1.8, 1)), ),
@@ -117,7 +119,7 @@ linesymbols = {
 
 def getLinePainterPath(name, size):
     """Get a painter path for line like objects."""
-    path = qt4.QPainterPath()
+    path = qt.QPainterPath()
     for lines in linesymbols[name]:
         path.moveTo(lines[0][0]*size, lines[0][1]*size)
         for x, y in lines[1:]:
@@ -206,124 +208,124 @@ polygons = {
 
 def addPolyPath(path, vals):
     """Add a polygon with the list of x,y pts as tuples in vals."""
-    poly = qt4.QPolygonF()
+    poly = qt.QPolygonF()
     for x, y in vals:
-        poly.append( qt4.QPointF(x, y) )
+        poly.append( qt.QPointF(x, y) )
     path.addPolygon(poly)
     path.closeSubpath()
 
 def getPolygonPainterPath(name, size):
     """Create a poly path for a polygon."""
-    path = qt4.QPainterPath()
+    path = qt.QPainterPath()
     addPolyPath(path, N.array(polygons[name])*size)
     return path
 
 #######################################################################
 ## draw symbols using a QPainterPath
 
-def squarePath(painter, path, size):
+def squarePath(path, size, linewidth):
     """Square path of size given."""
-    path.addRect( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addRect( qt.QRectF(-size, -size, size*2, size*2) )
 
-def circlePath(painter, path, size):
+def circlePath(path, size, linewidth):
     """Circle path of size given."""
-    path.addEllipse( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addEllipse( qt.QRectF(-size, -size, size*2, size*2) )
 
-def circlePlusPath(painter, path, size):
+def circlePlusPath(path, size, linewidth):
     """Circle path with plus."""
-    path.addEllipse( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addEllipse( qt.QRectF(-size, -size, size*2, size*2) )
     path.moveTo(0, -size)
     path.lineTo(0, size)
     path.moveTo(-size, 0)
     path.lineTo(size, 0)
 
-def circleCrossPath(painter, path, size):
+def circleCrossPath(path, size, linewidth):
     """Circle path with cross."""
-    path.addEllipse( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addEllipse( qt.QRectF(-size, -size, size*2, size*2) )
     m = N.sqrt(2.)*size*0.5
     path.moveTo(-m, -m)
     path.lineTo(m, m)
     path.moveTo(-m, m)
     path.lineTo(m, -m)
 
-def circlePairPathHorz(painter, path, size):
+def circlePairPathHorz(path, size, linewidth):
     """2 circles next to each other (horizontal)."""
-    path.addEllipse( qt4.QRectF(-size, -size*0.5, size, size) )
-    path.addEllipse( qt4.QRectF(0,  -size*0.5, size, size) )
+    path.addEllipse( qt.QRectF(-size, -size*0.5, size, size) )
+    path.addEllipse( qt.QRectF(0,  -size*0.5, size, size) )
 
-def circlePairPathVert(painter, path, size):
+def circlePairPathVert(path, size, linewidth):
     """2 circles next to each other (vertical)."""
-    path.addEllipse( qt4.QRectF(-size*0.5, -size, size, size) )
-    path.addEllipse( qt4.QRectF(-size*0.5, 0, size, size) )
+    path.addEllipse( qt.QRectF(-size*0.5, -size, size, size) )
+    path.addEllipse( qt.QRectF(-size*0.5, 0, size, size) )
 
-def ellipseHorzPath(painter, path, size):
+def ellipseHorzPath(path, size, linewidth):
     """Horizontal ellipse path."""
-    path.addEllipse( qt4.QRectF(-size, -size*0.5, size*2, size) )
+    path.addEllipse( qt.QRectF(-size, -size*0.5, size*2, size) )
 
-def ellipseVertPath(painter, path, size):
+def ellipseVertPath(path, size, linewidth):
     """Vertical ellipse path."""
-    path.addEllipse( qt4.QRectF(-size*0.5, -size, size, size*2) )
+    path.addEllipse( qt.QRectF(-size*0.5, -size, size, size*2) )
 
-def circleHolePath(painter, path, size):
+def circleHolePath(path, size, linewidth):
     """Circle with centre missing."""
-    circlePath(painter, path, size)
-    circlePath(painter, path, size*0.5)
+    circlePath(path, size, linewidth)
+    circlePath(path, size*0.5, linewidth)
 
-def squarePlusPath(painter, path, size):
+def squarePlusPath(path, size, linewidth):
     """Square with plus sign."""
-    path.addRect( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addRect( qt.QRectF(-size, -size, size*2, size*2) )
     path.moveTo(0, -size)
     path.lineTo(0, size)
     path.moveTo(-size, 0)
     path.lineTo(size, 0)
 
-def squareCrossPath(painter, path, size):
+def squareCrossPath(path, size, linewidth):
     """Square with cross sign."""
-    path.addRect( qt4.QRectF(-size, -size, size*2, size*2) )
+    path.addRect( qt.QRectF(-size, -size, size*2, size*2) )
     path.moveTo(-size, -size)
     path.lineTo(size, size)
     path.moveTo(-size, size)
     path.lineTo(size, -size)
 
-def squareHolePath(painter, path, size):
+def squareHolePath(path, size, linewidth):
     """Square with centre missing."""
-    path.addRect( qt4.QRectF(-size, -size, size*2, size*2) )
-    path.addRect( qt4.QRectF(-size*0.5, -size*0.5, size, size) )
+    path.addRect( qt.QRectF(-size, -size, size*2, size*2) )
+    path.addRect( qt.QRectF(-size*0.5, -size*0.5, size, size) )
 
-def diamondHolePath(painter, path, size):
+def diamondHolePath(path, size, linewidth):
     """Diamond with centre missing."""
     pts = N.array(polygons['diamond'])*size
     addPolyPath(path, pts)
     addPolyPath(path, pts*0.5)
 
-def pentagonHolePath(painter, path, size):
+def pentagonHolePath(path, size, linewidth):
     """Pentagon with centre missing."""
     pts = N.array(polygons['pentagon'])*size
     addPolyPath(path, pts)
     addPolyPath(path, pts*0.5)
 
-def squareRoundedPath(painter, path, size):
+def squareRoundedPath(path, size, linewidth):
     """A square with rounded corners."""
     path.addRoundedRect(
-        qt4.QRectF(-size, -size, size*2, size*2),
-        50, 50, qt4.Qt.RelativeSize)
+        qt.QRectF(-size, -size, size*2, size*2),
+        50, 50, qt.Qt.RelativeSize)
 
-def dotPath(painter, path, size):
+def dotPath(path, size, linewidth):
     """Draw a dot."""
-    w = painter.pen().widthF()
-    path.addEllipse( qt4.QRectF(-w*0.5, -w*0.5, w, w) )
+    path.addEllipse(qt.QRectF(
+        -linewidth*0.5, -linewidth*0.5, linewidth, linewidth))
 
-def bullseyePath(painter, path, size):
+def bullseyePath(path, size, linewidth):
     """A filled circle inside a filled circle."""
-    path.setFillRule(qt4.Qt.WindingFill)
-    circlePath(painter, path, size)
-    circlePath(painter, path, size*0.5)
+    path.setFillRule(qt.Qt.WindingFill)
+    circlePath(path, size, linewidth)
+    circlePath(path, size*0.5, linewidth)
 
-def circleDotPath(painter, path, size):
+def circleDotPath(path, size, linewidth):
     """A dot inside a circle."""
-    path.setFillRule(qt4.Qt.WindingFill)
-    circlePath(painter, path, size)
-    dotPath(painter, path, size)
+    path.setFillRule(qt.Qt.WindingFill)
+    circlePath(path, size, linewidth)
+    dotPath(path, size, linewidth)
 
 pathsymbols = {
     'square': squarePath,
@@ -346,13 +348,33 @@ pathsymbols = {
     'circledot': circleDotPath,
     }
 
-def getSymbolPainterPath(painter, name, size):
+def getSymbolPainterPath(name, size, linewidth):
     """Get a painter path for a symbol shape."""
-    path = qt4.QPainterPath()
-    pathsymbols[name](painter, path, size)
+    path = qt.QPainterPath()
+    pathsymbols[name](path, size, linewidth)
     return path
 
-def getPainterPath(painter, name, size):
+# translate arrow shapes to point types (we reuse them)
+arrow_translate = {
+    'none': 'none',
+    'arrow': '_arrow',
+    'arrownarrow': '_arrownarrow',
+    'arrowtriangle': '_arrowtriangle',
+    'arrowreverse': '_arrowreverse',
+    'linearrow': '_linearrow',
+    'linearrowreverse': '_linearrowreverse',
+    'bar': 'linevert',
+    'linecross': 'linecross',
+    'asterisk': 'asterisk',
+    'circle': 'circle',
+    'square': 'square',
+    'diamond': 'diamond',
+}
+
+#######################################################################
+## external interfaces
+
+def getPointPainterPath(name, size, linewidth):
     """Return a painter path for the name and size.
 
     Returns (painterpath, enablefill)."""
@@ -361,15 +383,12 @@ def getPainterPath(painter, name, size):
     elif name in polygons:
         return getPolygonPainterPath(name, size), True
     elif name in pathsymbols:
-        return getSymbolPainterPath(painter, name, size), True
+        return getSymbolPainterPath(name, size, linewidth), True
     elif name == 'none':
-        return qt4.QPainterPath(), True
+        return qt.QPainterPath(), True
     else:
         raise ValueError("Invalid marker name %s" % name)
 
-#######################################################################
-## external interfaces
-
 # list of codes supported
 MarkerCodes = (
     'none',
@@ -400,6 +419,7 @@ MarkerCodes = (
     'limitleftaway2', 'limitrightaway2',
     'arrowupperleftaway', 'arrowupperrightaway',
     'arrowlowerrightaway', 'arrowlowerleftaway',
+    'lineup', 'linedown', 'lineleft', 'lineright',
     )
 
 def plotMarkers(painter, xpos, ypos, markername, markersize, scaling=None,
@@ -425,14 +445,15 @@ def plotMarkers(painter, xpos, ypos, markername, markersize, scaling=None,
 
     # get sharper angles and more exact positions using these settings
     pen = painter.pen()
-    pen.setJoinStyle( qt4.Qt.MiterJoin )
+    pen.setJoinStyle( qt.Qt.MiterJoin )
     painter.setPen(pen)
 
     # get path to draw and whether to fill
-    path, fill = getPainterPath(painter, markername, markersize)
+    path, fill = getPointPainterPath(
+        markername, markersize, painter.pen().widthF())
     if not fill:
         # turn off brush
-        painter.setBrush( qt4.QBrush() )
+        painter.setBrush( qt.QBrush() )
 
     # if using colored points
     colorimg = None
@@ -443,7 +464,6 @@ def plotMarkers(painter, xpos, ypos, markername, markersize, scaling=None,
         colorimg = colormap.applyColorMap(
             cmap, 'linear', color2d, 0., 1., trans)
 
-    # this is the fast (C++) or slow (python) helper
     plotPathsToPainter(painter, path, xpos, ypos, scaling, clip, colorimg,
                        scaleline)
 
@@ -469,6 +489,9 @@ arrow_translate = {
     'circle': 'circle',
     'square': 'square',
     'diamond': 'diamond',
+    'lineup': 'lineup',
+    'linedown': 'linedown',
+    'lineextend': 'lineright',
 }
 
 # codes of allowable arrows
@@ -479,6 +502,8 @@ ArrowCodes = ( 'none', 'arrow', 'arrownarrow',
                'bar', 'linecross',
                'asterisk',
                'circle', 'square', 'diamond',
+               'lineup', 'linedown',
+               'lineextend',
                )
 
 def plotLineArrow(painter, xpos, ypos, length, angle,
@@ -494,17 +519,17 @@ def plotLineArrow(painter, xpos, ypos, length, angle,
     painter.translate(xpos, ypos)
     painter.rotate(angle)
 
-    # draw line between points
-    painter.drawLine( qt4.QPointF(0., 0.),
-                      qt4.QPointF(length, 0.) )
-
     # plot marker at one end of line
-    plotMarker(painter, length, 0., 
-               arrow_translate[arrowright], arrowsize)
+    plotMarker(painter, length, 0., arrow_translate[arrowright], arrowsize)
 
     # plot reversed marker at other end
     painter.scale(-1, 1)
-    plotMarker(painter, 0., 0., 
-               arrow_translate[arrowleft], arrowsize)
+    plotMarker(painter, 0, 0, arrow_translate[arrowleft], arrowsize)
+
+    pen = painter.pen()
+    pen.setCapStyle(qt.Qt.FlatCap)
+    painter.setPen(pen)
+    painter.scale(-1, 1)
+    painter.drawLine(qt.QPointF(0, 0), qt.QPointF(length, 0))
 
     painter.restore()
