@@ -25,14 +25,15 @@ import os.path
 import sys
 import glob
 import re
+import datetime
 
 try:
     import h5py
 except ImportError:
     h5py = None
 
-from ..compat import cstr, cstrerror
-from .. import qtall as qt4
+from ..compat import cstr, cstrerror, cgetcwd, cbytes
+from .. import qtall as qt
 
 from .. import document
 from .. import utils
@@ -47,7 +48,7 @@ from .datanavigator import DataNavigatorWindow
 
 def _(text, disambiguation=None, context='MainWindow'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # shortcut to this
 setdb = setting.settingdb
@@ -59,7 +60,9 @@ class DBusWinInterface(vzdbus.Object):
 
     def __init__(self, actions, index):
         prefix = '/Windows/%i/Actions' % index
-        vzdbus.Object.__init__(self, vzdbus.sessionbus, prefix)
+        # possible exception in dbus means we have to check sessionbus
+        if vzdbus.sessionbus is not None:
+            vzdbus.Object.__init__(self, vzdbus.sessionbus, prefix)
         self.actions = actions
 
     @vzdbus.method(dbus_interface=interface, out_signature='as')
@@ -72,17 +75,17 @@ class DBusWinInterface(vzdbus.Object):
         """Activate action given."""
         self.actions[action].trigger()
 
-class MainWindow(qt4.QMainWindow):
+class MainWindow(qt.QMainWindow):
     """ The main window class for the application."""
 
     # this is emitted when a dialog is opened by the main window
-    dialogShown = qt4.pyqtSignal(qt4.QWidget)
+    dialogShown = qt.pyqtSignal(qt.QWidget)
     # emitted when a document is opened
-    documentOpened = qt4.pyqtSignal()
+    documentOpened = qt.pyqtSignal()
 
     windows = []
     @classmethod
-    def CreateWindow(cls, filename=None):
+    def CreateWindow(cls, filename=None, mode='graph'):
         """Window factory function.
 
         If filename is given then that file is loaded into the window.
@@ -96,23 +99,33 @@ class MainWindow(qt4.QMainWindow):
             # load document
             win.openFileInWindow(filename)
         else:
-            win.setupDefaultDoc()
+            win.setupDefaultDoc(mode)
 
         # try to select first graph of first page
         win.treeedit.doInitialWidgetSelect()
 
         cls.windows.append(win)
 
-        # check if tutorial wanted
-        if not setting.settingdb['ask_tutorial']:
+        # check if tutorial wanted (only for graph mode)
+        if not setting.settingdb['ask_tutorial'] and mode=='graph':
             win.askTutorial()
-        # don't ask again
-        setting.settingdb['ask_tutorial'] = True
+            # don't ask again
+            setting.settingdb['ask_tutorial'] = True
+
+        # check if version check is ok
+        win.askVersionCheck()
+        # periodically do the check
+        win.doVersionCheck()
+
+        # is it ok to do feedback?
+        win.askFeedbackCheck()
+        # periodically send feedback
+        win.doFeedback()
 
         return win
 
     def __init__(self, *args):
-        qt4.QMainWindow.__init__(self, *args)
+        qt.QMainWindow.__init__(self, *args)
         self.setAcceptDrops(True)
 
         # icon and different size variations
@@ -139,30 +152,30 @@ class MainWindow(qt4.QMainWindow):
 
         # likewise with the tree-editing window
         self.treeedit = treeeditwindow.TreeEditDock(self.document, self)
-        self.addDockWidget(qt4.Qt.LeftDockWidgetArea, self.treeedit)
+        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.treeedit)
         self.propdock = treeeditwindow.PropertiesDock(self.document,
                                                       self.treeedit, self)
-        self.addDockWidget(qt4.Qt.LeftDockWidgetArea, self.propdock)
+        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.propdock)
         self.formatdock = treeeditwindow.FormatDock(self.document,
                                                     self.treeedit, self)
-        self.addDockWidget(qt4.Qt.LeftDockWidgetArea, self.formatdock)
+        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.formatdock)
         self.datadock = DataNavigatorWindow(self.document, self, self)
-        self.addDockWidget(qt4.Qt.RightDockWidgetArea, self.datadock)
+        self.addDockWidget(qt.Qt.RightDockWidgetArea, self.datadock)
 
         # make the console window a dock
         self.console = consolewindow.ConsoleWindow(self.document,
                                                    self)
         self.console.hide()
         self.interpreter = self.console.interpreter
-        self.addDockWidget(qt4.Qt.BottomDockWidgetArea, self.console)
+        self.addDockWidget(qt.Qt.BottomDockWidgetArea, self.console)
 
         # assemble the statusbar
-        statusbar = self.statusbar = qt4.QStatusBar(self)
+        statusbar = self.statusbar = qt.QStatusBar(self)
         self.setStatusBar(statusbar)
         self.updateStatusbar(_('Ready'))
 
         # a label for the picker readout
-        self.pickerlabel = qt4.QLabel(statusbar)
+        self.pickerlabel = qt.QLabel(statusbar)
         self._setPickerFont(self.pickerlabel)
         statusbar.addPermanentWidget(self.pickerlabel)
         self.pickerlabel.hide()
@@ -170,26 +183,26 @@ class MainWindow(qt4.QMainWindow):
         # plot queue - how many plots are currently being drawn
         self.plotqueuecount = 0
         self.plot.sigQueueChange.connect(self.plotQueueChanged)
-        self.plotqueuelabel = qt4.QLabel()
+        self.plotqueuelabel = qt.QLabel()
         self.plotqueuelabel.setToolTip(_("Number of rendering jobs remaining"))
         statusbar.addWidget(self.plotqueuelabel)
         self.plotqueuelabel.show()
 
         # a label for the cursor position readout
-        self.axisvalueslabel = qt4.QLabel(statusbar)
+        self.axisvalueslabel = qt.QLabel(statusbar)
         statusbar.addPermanentWidget(self.axisvalueslabel)
         self.axisvalueslabel.show()
         self.slotUpdateAxisValues(None)
 
         # a label for the page number readout
-        self.pagelabel = qt4.QLabel(statusbar)
+        self.pagelabel = qt.QLabel(statusbar)
         statusbar.addPermanentWidget(self.pagelabel)
         self.pagelabel.show()
 
         # working directory - use previous one
-        self.dirname = setdb.get('dirname', qt4.QDir.homePath())
+        self.dirname = setdb.get('dirname', qt.QDir.homePath())
         if setdb['dirname_usecwd']:
-            self.dirname = os.getcwd()
+            self.dirname = cgetcwd()
 
         # connect plot signals to main window
         self.plot.sigUpdatePage.connect(self.slotUpdatePage)
@@ -231,13 +244,13 @@ class MainWindow(qt4.QMainWindow):
 
     def dragEnterEvent(self, event):
         """Check whether event is valid to be dropped."""
-        if (event.provides("text/uri-list") and
+        if (event.mimeData().hasUrls() and
             self._getVeuszDropFiles(event)):
             event.acceptProposedAction()
 
     def dropEvent(self, event):
         """Respond to a drop event on the current window"""
-        if event.provides("text/uri-list"):
+        if event.mimeData().hasUrls():
             files = self._getVeuszDropFiles(event)
             if files:
                 if self.document.isBlank():
@@ -256,16 +269,20 @@ class MainWindow(qt4.QMainWindow):
             return []
         else:
             # get list of vsz files dropped
-            urls = [u.path() for u in mime.urls()]
+            urls = [u.toLocalFile() for u in mime.urls()]
             urls = [u for u in urls if os.path.splitext(u)[1] == '.vsz']
             return urls
 
-    def setupDefaultDoc(self):
+    def setupDefaultDoc(self, mode):
         """Setup default document."""
 
         if not self.documentsetup:
             # add page and default graph
-            self.document.makeDefaultDoc()
+            self.document.makeDefaultDoc(mode)
+
+            # set color theme
+            self.document.basewidget.settings.get(
+                'colorTheme').set(setting.settingdb['colortheme_default'])
 
             # load defaults if set
             self.loadDefaultStylesheet()
@@ -282,7 +299,7 @@ class MainWindow(qt4.QMainWindow):
                 self.document.applyOperation(
                     document.OperationLoadStyleSheet(filename) )
             except EnvironmentError as e:
-                qt4.QMessageBox.warning(
+                qt.QMessageBox.warning(
                     self, _("Error - Veusz"),
                     _("Unable to load default stylesheet '%s'\n\n%s") %
                     (filename, cstrerror(e)))
@@ -299,7 +316,7 @@ class MainWindow(qt4.QMainWindow):
                 self.document.applyOperation(
                     document.OperationLoadCustom(filename) )
             except EnvironmentError as e:
-                qt4.QMessageBox.warning(
+                qt.QMessageBox.warning(
                     self, _("Error - Veusz"),
                     _("Unable to load custom definitions '%s'\n\n%s") %
                     (filename, cstrerror(e)))
@@ -406,20 +423,48 @@ class MainWindow(qt4.QMainWindow):
         # these are actions for main menu toolbars and menus
         a = utils.makeAction
         self.vzactions = {
-            'file.new':
-                a(self, _('New document'), _('&New'),
-                  self.slotFileNew,
-                  icon='kde-document-new', key='Ctrl+N'),
+            'file.new.menu':
+                a(self, _('New document'), _('New'),
+                  None,
+                  icon='kde-document-new'),
+            'file.new.graph':
+                a(self,
+                  _('New graph document'),
+                  _('&New graph document'),
+                  self.slotFileNewGraph,
+                  icon='kde-document-new-graph', key='Ctrl+N'),
+            'file.new.polar':
+                a(self,
+                  _('New polar plot document'),
+                  _('New polar document'),
+                  self.slotFileNewPolar,
+                  icon='kde-document-new-polar'),
+            'file.new.ternary':
+                a(self,
+                  _('New ternary plot document'),
+                  _('New ternary document'),
+                  self.slotFileNewTernary,
+                  icon='kde-document-new-ternary'),
+            'file.new.graph3d':
+                a(self,
+                  _('New 3D plot document'),
+                  _('New 3D document'),
+                  self.slotFileNewGraph3D,
+                  icon='kde-document-new-graph3d'),
+
             'file.open':
                 a(self, _('Open a document'), _('&Open...'),
                   self.slotFileOpen,
                   icon='kde-document-open', key='Ctrl+O'),
+            'file.reload':
+                a(self, _('Reload document from saved version'),
+                  _('Reload...'), self.slotFileReload),
             'file.save':
                 a(self, _('Save the document'), _('&Save'),
                   self.slotFileSave,
                   icon='kde-document-save', key='Ctrl+S'),
             'file.saveas':
-                a(self, _('Save the current graph under a new name'),
+                a(self, _('Save the current document under a new name'),
                   _('Save &As...'), self.slotFileSaveAs,
                   icon='kde-document-save-as'),
             'file.print':
@@ -452,7 +497,8 @@ class MainWindow(qt4.QMainWindow):
                   self.slotEditPreferences,
                   icon='veusz-edit-prefs'),
             'edit.custom':
-                a(self, _('Edit custom functions and constants'),
+                a(self,
+                  _('Edit custom functions, constants, colors and colormaps'),
                   _('Custom definitions...'),
                   self.slotEditCustom,
                   icon='veusz-edit-custom'),
@@ -523,12 +569,13 @@ class MainWindow(qt4.QMainWindow):
             'help.home':
                 a(self, _('Go to the Veusz home page on the internet'),
                   _('Home page'), self.slotHelpHomepage),
-            'help.project':
-                a(self, _('Go to the Veusz project page on the internet'),
-                  _('GNA Project page'), self.slotHelpProjectPage),
             'help.bug':
                 a(self, _('Report a bug on the internet'),
                   _('Suggestions and bugs'), self.slotHelpBug),
+            'help.update':
+                a(self, _('Download latest version'),
+                  _('Download latest version'), self.slotHelpUpdate),
+
             'help.tutorial':
                 a(self, _('An interactive Veusz tutorial'),
                   _('Tutorial'), self.slotHelpTutorial),
@@ -538,20 +585,29 @@ class MainWindow(qt4.QMainWindow):
             }
 
         # create main toolbar
-        tb = self.maintoolbar = qt4.QToolBar(_("Main toolbar - Veusz"), self)
+        tb = self.maintoolbar = qt.QToolBar(_("Main toolbar - Veusz"), self)
         iconsize = setdb['toolbar_size']
-        tb.setIconSize(qt4.QSize(iconsize, iconsize))
+        tb.setIconSize(qt.QSize(iconsize, iconsize))
         tb.setObjectName('veuszmaintoolbar')
-        self.addToolBar(qt4.Qt.TopToolBarArea, tb)
-        utils.addToolbarActions(tb, self.vzactions,
-                                ('file.new', 'file.open', 'file.save',
-                                 'file.print', 'file.export'))
+        self.addToolBar(qt.Qt.TopToolBarArea, tb)
+
+        utils.makeMenuGroupSaved(
+            'file.new.menu', self, self.vzactions, (
+                    'file.new.graph', 'file.new.graph3d',
+                    'file.new.polar', 'file.new.ternary',
+            )
+        )
+
+        utils.addToolbarActions(
+            tb, self.vzactions,
+            ('file.new.menu', 'file.open', 'file.save',
+             'file.print', 'file.export'))
 
         # data toolbar
-        tb = self.datatoolbar = qt4.QToolBar(_("Data toolbar - Veusz"), self)
-        tb.setIconSize(qt4.QSize(iconsize, iconsize))
+        tb = self.datatoolbar = qt.QToolBar(_("Data toolbar - Veusz"), self)
+        tb.setIconSize(qt.QSize(iconsize, iconsize))
         tb.setObjectName('veuszdatatoolbar')
-        self.addToolBar(qt4.Qt.TopToolBarArea, tb)
+        self.addToolBar(qt.Qt.TopToolBarArea, tb)
         utils.addToolbarActions(
             tb, self.vzactions,
             ('data.import', 'data.edit',
@@ -560,8 +616,12 @@ class MainWindow(qt4.QMainWindow):
 
         # menu structure
         filemenu = [
-            'file.new', 'file.open',
+            ['file.new', _('New'),
+             ['file.new.graph', 'file.new.graph3d', 'file.new.polar',
+              'file.new.ternary']],
+            'file.open',
             ['file.filerecent', _('Open &Recent'), []],
+            'file.reload',
             '',
             'file.save', 'file.saveas',
             '',
@@ -602,7 +662,7 @@ class MainWindow(qt4.QMainWindow):
             'data.reload',
             ]
         helpmenu = [
-            'help.home', 'help.project', 'help.bug',
+            'help.home', 'help.bug', 'help.update',
             '',
             'help.tutorial',
             '',
@@ -628,6 +688,9 @@ class MainWindow(qt4.QMainWindow):
         self.menus = {}
         utils.constructMenus(self.menuBar(), self.menus, menus, self.vzactions)
 
+        # set icon for File->New
+        self.menus['file.new'].setIcon(utils.getIcon('kde-document-new'))
+
         self.populateExamplesMenu()
 
     def _setPickerFont(self, label):
@@ -771,28 +834,24 @@ class MainWindow(qt4.QMainWindow):
 
     def slotHelpHomepage(self):
         """Go to the veusz homepage."""
-        qt4.QDesktopServices.openUrl(qt4.QUrl('http://home.gna.org/veusz/'))
-
-    def slotHelpProjectPage(self):
-        """Go to the veusz project page."""
-        qt4.QDesktopServices.openUrl(qt4.QUrl('http://gna.org/projects/veusz/'))
+        qt.QDesktopServices.openUrl(qt.QUrl('https://veusz.github.io/'))
 
     def slotHelpBug(self):
         """Go to the veusz bug page."""
-        qt4.QDesktopServices.openUrl(
-            qt4.QUrl('https://gna.org/bugs/?group=veusz') )
+        qt.QDesktopServices.openUrl(
+            qt.QUrl('https://github.com/veusz/veusz/issues') )
 
     def askTutorial(self):
         """Ask if tutorial wanted."""
-        retn = qt4.QMessageBox.question(
+        retn = qt.QMessageBox.question(
             self, _("Veusz Tutorial"),
             _("Veusz includes a tutorial to help get you started.\n"
               "Would you like to start the tutorial now?\n"
               "If not, you can access it later through the Help menu."),
-            qt4.QMessageBox.Yes | qt4.QMessageBox.No
+            qt.QMessageBox.Yes | qt.QMessageBox.No
             )
 
-        if retn == qt4.QMessageBox.Yes:
+        if retn == qt.QMessageBox.Yes:
             self.slotHelpTutorial()
 
     def slotHelpTutorial(self):
@@ -801,7 +860,7 @@ class MainWindow(qt4.QMainWindow):
             # run the tutorial
             from .tutorial import TutorialDock
             tutdock = TutorialDock(self.document, self, self)
-            self.addDockWidget(qt4.Qt.RightDockWidgetArea, tutdock)
+            self.addDockWidget(qt.Qt.RightDockWidgetArea, tutdock)
             tutdock.show()
         else:
             # open up a blank window for tutorial
@@ -813,28 +872,111 @@ class MainWindow(qt4.QMainWindow):
         from ..dialogs.aboutdialog import AboutDialog
         AboutDialog(self).exec_()
 
+    def askVersionCheck(self, mininterval=2):
+        """Check with user whether to do version checks.
+
+        This is only done after the user has been using the program
+        for mininterval days
+
+        """
+
+        dayssinceinstall = (
+            datetime.date.today() -
+            datetime.date(*setting.settingdb['install_date'])).days
+        if (dayssinceinstall<mininterval or
+            setting.settingdb['vercheck_asked_user'] or
+            setting.settingdb['vercheck_disabled'] or
+            utils.disableVersionChecks):
+            return
+
+        retn = qt.QMessageBox.question(
+            self, _("Version check"),
+            _("Veusz will periodically check for new Veusz versions and\n"
+              "let you know if there is a new one available.\n\n"
+              "Is this ok? This choice can be changed in Preferences."),
+            qt.QMessageBox.Yes | qt.QMessageBox.No,
+            qt.QMessageBox.Yes
+            )
+
+        setting.settingdb['vercheck_disabled'] = retn==qt.QMessageBox.No
+        setting.settingdb['vercheck_asked_user'] = True
+
+    def doVersionCheck(self):
+        """Check whether there is a new version.
+        """
+        self.vzactions['help.update'].setVisible(False)
+
+        # check is done asynchronously
+        thread = utils.VersionCheckThread(self)
+        thread.newversion.connect(self.slotNewVersion)
+        thread.finished.connect(thread.deleteLater)
+        thread.start()
+
+    def askFeedbackCheck(self, mininterval=3):
+        """Check with user whether to do feedback.
+
+        This is only done after the user has been using the program
+        for mininterval days
+
+        """
+
+        dayssinceinstall = (
+            datetime.date.today() -
+            datetime.date(*setting.settingdb['install_date'])).days
+        if (dayssinceinstall<mininterval or
+            setting.settingdb['feedback_asked_user'] or
+            setting.settingdb['feedback_disabled'] or
+            utils.disableFeedback):
+            return
+
+        retn = qt.QMessageBox.question(
+            self, _("Send automatic anonymous feedback"),
+            _("Veusz can automatically send anonymous feedback "
+              "to the developers, with information about the version "
+              "of software dependencies, the computer language and how "
+              "often features are used.\n\n"
+              "Is this ok? This choice can be changed in Preferences."),
+            qt.QMessageBox.Yes | qt.QMessageBox.No,
+            qt.QMessageBox.Yes
+            )
+
+        setting.settingdb['feedback_disabled'] = retn==qt.QMessageBox.No
+        setting.settingdb['feedback_asked_user'] = True
+
+    def doFeedback(self):
+        """Give feedback."""
+        thread = utils.FeedbackCheckThread(self)
+        thread.start()
+
+    def slotNewVersion(self, ver):
+        """Called when there is a new version."""
+        msg = _('Veusz %s is available for download - see Help menu') % ver
+        self.statusBar().showMessage(msg, 5000)
+        self.vzactions['help.update'].setText(
+            _('Download new Veusz %s') % ver)
+        self.vzactions['help.update'].setVisible(True)
+
+    def slotHelpUpdate(self):
+        """Open web page to update."""
+        qt.QDesktopServices.openUrl(qt.QUrl(
+            'https://veusz.github.io/download/'))
+
     def queryOverwrite(self):
         """Do you want to overwrite the current document.
 
-        Returns qt4.QMessageBox.(Yes,No,Cancel)."""
+        Returns qt.QMessageBox.(Yes,No,Cancel)."""
 
         # include filename in mesage box if we can
         filetext = ''
         if self.filename:
             filetext = " '%s'" % os.path.basename(self.filename)
 
-        # show message box
-        mb = qt4.QMessageBox(_("Save file?"),
-                             _("Document%s was modified. Save first?") % filetext,
-                             qt4.QMessageBox.Warning,
-                             qt4.QMessageBox.Yes | qt4.QMessageBox.Default,
-                             qt4.QMessageBox.No,
-                             qt4.QMessageBox.Cancel | qt4.QMessageBox.Escape,
-                             self)
-        mb.setButtonText(qt4.QMessageBox.Yes, _("&Save"))
-        mb.setButtonText(qt4.QMessageBox.No, _("&Discard"))
-        mb.setButtonText(qt4.QMessageBox.Cancel, _("&Cancel"))
-        return mb.exec_()
+        return qt.QMessageBox.warning(
+            self,
+            _("Save file?"),
+            _("Document%s was modified. Save first?") % filetext,
+            qt.QMessageBox.Save | qt.QMessageBox.Discard |
+            qt.QMessageBox.Cancel)
 
     def closeEvent(self, event):
         """Before closing, check whether we need to save first."""
@@ -842,10 +984,10 @@ class MainWindow(qt4.QMainWindow):
         # if the document has been modified then query user for saving
         if self.document.isModified():
             v = self.queryOverwrite()
-            if v == qt4.QMessageBox.Cancel:
+            if v == qt.QMessageBox.Cancel:
                 event.ignore()
                 return
-            elif v == qt4.QMessageBox.Yes:
+            elif v == qt.QMessageBox.Save:
                 self.slotFileSave()
 
         # store working directory
@@ -857,7 +999,7 @@ class MainWindow(qt4.QMainWindow):
 
         # store docked windows
         data = self.saveState().data()
-        setdb['geometry_mainwindowstate'] = data
+        setdb['geometry_mainwindowstate'] = cbytes(data)
 
         # save current setting db
         setdb.writeSettings()
@@ -869,29 +1011,44 @@ class MainWindow(qt4.QMainWindow):
 
         # count number of main windows shown
         nummain = 0
-        for w in qt4.qApp.topLevelWidgets():
-            if isinstance(w, qt4.QMainWindow):
+        for w in qt.qApp.topLevelWidgets():
+            if isinstance(w, qt.QMainWindow):
                 nummain += 1
 
         # if we can restore the geometry, do so
         if 'geometry_mainwindow' in setdb:
             geometry = setdb['geometry_mainwindow']
-            self.resize( qt4.QSize(geometry[2], geometry[3]) )
+            self.resize( qt.QSize(geometry[2], geometry[3]) )
             if nummain <= 1:
-                geomrect = qt4.QApplication.desktop().availableGeometry()
-                newpos = qt4.QPoint(geometry[0], geometry[1])
+                geomrect = qt.QApplication.desktop().availableGeometry()
+                newpos = qt.QPoint(geometry[0], geometry[1])
                 if geomrect.contains(newpos):
                     self.move(newpos)
 
         # restore docked window geometry
         if 'geometry_mainwindowstate' in setdb:
-            b = qt4.QByteArray(setdb['geometry_mainwindowstate'])
-            self.restoreState(b)
+            try:
+                self.restoreState(setdb['geometry_mainwindowstate'])
+            except Exception:
+                # type can be wrong if switching between Py2/3 PyQ4/5
+                pass
 
-    def slotFileNew(self):
-        """New file."""
+    def slotFileNewGraph(self):
+        """New file (graph)."""
         self.CreateWindow()
 
+    def slotFileNewPolar(self):
+        """New file (polar)."""
+        self.CreateWindow(mode='polar')
+
+    def slotFileNewTernary(self):
+        """New file (ternary)."""
+        self.CreateWindow(mode='ternary')
+
+    def slotFileNewGraph3D(self):
+        """New file (graph3d)."""
+        self.CreateWindow(mode='graph3d')
+
     def slotFileSave(self):
         """Save file."""
 
@@ -899,21 +1056,21 @@ class MainWindow(qt4.QMainWindow):
             self.slotFileSaveAs()
         else:
             # show busy cursor
-            qt4.QApplication.setOverrideCursor( qt4.QCursor(qt4.Qt.WaitCursor) )
+            qt.QApplication.setOverrideCursor( qt.QCursor(qt.Qt.WaitCursor) )
             try:
                 ext = os.path.splitext(self.filename)[1]
                 mode = 'hdf5' if ext == '.vszh5' else 'vsz'
                 self.document.save(self.filename, mode)
                 self.updateStatusbar(_("Saved to %s") % self.filename)
             except EnvironmentError as e:
-                qt4.QApplication.restoreOverrideCursor()
-                qt4.QMessageBox.critical(
+                qt.QApplication.restoreOverrideCursor()
+                qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to save document as '%s'\n\n%s") %
                     (self.filename, cstrerror(e)))
             else:
                 # restore the cursor
-                qt4.QApplication.restoreOverrideCursor()
+                qt.QApplication.restoreOverrideCursor()
 
     def updateTitlebar(self):
         """Put the filename into the title bar."""
@@ -934,10 +1091,10 @@ class MainWindow(qt4.QMainWindow):
         filters: list of filters
         """
 
-        fd = qt4.QFileDialog(self, dialogtitle)
+        fd = qt.QFileDialog(self, dialogtitle)
         fd.setDirectory(self.dirname)
-        fd.setFileMode(qt4.QFileDialog.AnyFile)
-        fd.setAcceptMode(qt4.QFileDialog.AcceptSave)
+        fd.setFileMode(qt.QFileDialog.AnyFile)
+        fd.setAcceptMode(qt.QFileDialog.AcceptSave)
         fd.setNameFilters(filters)
 
         # selected filetype is saved under a key constructed here
@@ -950,7 +1107,7 @@ class MainWindow(qt4.QMainWindow):
                 fd.selectNameFilter(filter)
 
         # okay was selected (and is okay to overwrite if it exists)
-        if fd.exec_() == qt4.QDialog.Accepted:
+        if fd.exec_() == qt.QDialog.Accepted:
             # save directory for next time
             self.dirname = fd.directory().absolutePath()
             # update the edit box
@@ -969,14 +1126,14 @@ class MainWindow(qt4.QMainWindow):
         filters: list of filters in format "Filetype (*.vsz)"
         """
 
-        fd = qt4.QFileDialog(self, dialogtitle)
+        fd = qt.QFileDialog(self, dialogtitle)
         fd.setDirectory(self.dirname)
-        fd.setFileMode( qt4.QFileDialog.ExistingFile )
-        fd.setAcceptMode( qt4.QFileDialog.AcceptOpen )
+        fd.setFileMode( qt.QFileDialog.ExistingFile )
+        fd.setAcceptMode( qt.QFileDialog.AcceptOpen )
         fd.setNameFilters(filters)
 
         # if the user chooses a file
-        if fd.exec_() == qt4.QDialog.Accepted:
+        if fd.exec_() == qt.QDialog.Accepted:
             # save directory for next time
             self.dirname = fd.directory().absolutePath()
 
@@ -985,7 +1142,7 @@ class MainWindow(qt4.QMainWindow):
                 with open(filename):
                     pass
             except EnvironmentError as e:
-                qt4.QMessageBox.critical(
+                qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to open '%s'\n\n%s") %
                     (filename, cstrerror(e)))
@@ -1023,34 +1180,50 @@ class MainWindow(qt4.QMainWindow):
         Return True if loaded ok
         """
 
-        class _unsafeCmdMsgBox(qt4.QMessageBox):
-            """Show document is unsafe."""
-            def __init__(self, window):
-                qt4.QMessageBox.__init__(
-                    self, _("Unsafe code in document"),
-                    _("The document '%s' contains potentially unsafe code "
-                      "which may damage your computer or data. Please check "
-                      "that the file comes from a trusted source.") % filename,
-                    qt4.QMessageBox.Warning,
-                    qt4.QMessageBox.Yes,
-                    qt4.QMessageBox.No | qt4.QMessageBox.Default,
-                    qt4.QMessageBox.NoButton,
-                    window)
-                self.setButtonText(qt4.QMessageBox.Yes, _("C&ontinue anyway"))
-                self.setButtonText(qt4.QMessageBox.No, _("&Stop loading"))
-
         def _callbackunsafe():
-            qt4.QApplication.restoreOverrideCursor()
-            v = _unsafeCmdMsgBox(self).exec_()
-            qt4.QApplication.setOverrideCursor( qt4.QCursor(qt4.Qt.WaitCursor) )
-            return v == qt4.QMessageBox.Yes
+            """Callback when loading document to ask whether ok to continue loading
+            if unsafe commands are found."""
+            qt.QApplication.restoreOverrideCursor()
+            msgbox = qt.QMessageBox(
+                qt.QMessageBox.Warning,
+                _("Unsafe code in document"),
+                _("The document '%s' contains potentially unsafe code "
+                  "which may damage your computer or data. Please check "
+                  "that the file comes from a trusted source.") % filename,
+                qt.QMessageBox.NoButton,
+                self)
+            cont = msgbox.addButton(_("C&ontinue anyway"), qt.QMessageBox.AcceptRole)
+            stop = msgbox.addButton(_("&Stop loading"), qt.QMessageBox.RejectRole)
+            msgbox.setDefaultButton(stop)
+            msgbox.exec_()
+            qt.QApplication.setOverrideCursor(qt.QCursor(qt.Qt.WaitCursor))
+            return msgbox.clickedButton() is cont
+
+        def _callbackimporterror(filename, error):
+            """Ask user if they want to give a new filename in case of import
+            error.
+            """
+            qt.QApplication.restoreOverrideCursor()
+            msgbox = qt.QMessageBox(self)
+            msgbox.setWindowTitle(_("Import error"))
+            msgbox.setText(
+                _("Could not import data from file '%s':\n\n %s") % (
+                    filename, error))
+            msgbox.setInformativeText(_("Do you want to look for another file?"))
+            msgbox.setStandardButtons(qt.QMessageBox.Yes | qt.QMessageBox.Cancel)
+            filename = None
+            if msgbox.exec_() == qt.QMessageBox.Yes:
+                filename = qt.QFileDialog.getOpenFileName(self, "Choose data file")
+                filename = filename[0] if filename else None
+            qt.QApplication.setOverrideCursor(qt.QCursor(qt.Qt.WaitCursor))
+            return filename
 
         # save stdout and stderr, then redirect to console
         stdout, stderr = sys.stdout, sys.stderr
         sys.stdout = self.console.con_stdout
         sys.stderr = self.console.con_stderr
 
-        qt4.QApplication.setOverrideCursor( qt4.QCursor(qt4.Qt.WaitCursor) )
+        qt.QApplication.setOverrideCursor( qt.QCursor(qt.Qt.WaitCursor) )
 
         try:
             # get loading mode
@@ -1067,21 +1240,22 @@ class MainWindow(qt4.QMainWindow):
             self.document.load(
                 filename,
                 mode=mode,
-                callbackunsafe=_callbackunsafe)
+                callbackunsafe=_callbackunsafe,
+                callbackimporterror=_callbackimporterror)
 
         except document.LoadError as e:
             from ..dialogs.errorloading import ErrorLoadingDialog
-            qt4.QApplication.restoreOverrideCursor()
+            qt.QApplication.restoreOverrideCursor()
             if e.backtrace:
                 d = ErrorLoadingDialog(self, filename, cstr(e), e.backtrace)
                 d.exec_()
             else:
-                qt4.QMessageBox.critical(
+                qt.QMessageBox.critical(
                     self, _("Error opening %s - Veusz") % filename,
                     cstr(e))
             return False
 
-        qt4.QApplication.restoreOverrideCursor()
+        qt.QApplication.restoreOverrideCursor()
 
         # need to remember to restore stdout, stderr
         sys.stdout, sys.stderr = stdout, stderr
@@ -1168,6 +1342,24 @@ class MainWindow(qt4.QMainWindow):
         else:
             menu.setEnabled(False)
 
+    def slotFileReload(self):
+        """Reload document from saved version."""
+
+        retn = qt.QMessageBox.warning(
+            self,
+            _("Reload file"),
+            _("Reload document from file, losing any changes?"),
+            qt.QMessageBox.Yes | qt.QMessageBox.Cancel,
+            qt.QMessageBox.Cancel)
+        if retn == qt.QMessageBox.Yes:
+            if not os.path.exists(self.filename):
+                qt.QMessageBox.critical(
+                    self,
+                    _("Reload file"),
+                    _("File %s no longer exists") % self.filename)
+            else:
+                self.openFileInWindow(self.filename)
+
     def slotFileExport(self):
         """Export the graph."""
         from ..dialogs.export import ExportDialog
@@ -1185,13 +1377,17 @@ class MainWindow(qt4.QMainWindow):
         # enable/disable file, save menu item
         self.vzactions['file.save'].setEnabled(ismodified)
 
+        # enable/disable reloading from saved document
+        self.vzactions['file.reload'].setEnabled(
+            bool(self.filename) and ismodified)
+
     def slotFileClose(self):
         """File close window chosen."""
         self.close()
 
     def slotFileQuit(self):
         """File quit chosen."""
-        qt4.qApp.closeAllWindows()
+        qt.qApp.closeAllWindows()
 
     def slotUpdatePage(self, number):
         """Update page number when the plot window says so."""
@@ -1250,11 +1446,11 @@ class MainWindow(qt4.QMainWindow):
         if setdb['picker_to_console']:
             self.console.appendOutput(t + "\n", 'error')
         if setdb['picker_to_clipboard']:
-            clipboard = qt4.QApplication.clipboard()
+            clipboard = qt.QApplication.clipboard()
             if clipboard.mimeData().hasText():
                 clipboard.setText(clipboard.text()+"\n"+t)
             else:
-                qt4.QApplication.clipboard().setText(t)
+                qt.QApplication.clipboard().setText(t)
 
     def slotAllowedImportsDoc(self, module, names):
         """Are allowed imports?"""
